'use strict';

const { promisify } = require('util');
const request = promisify(require('request'));

async function bitbucketRequest({
  url,
  qs,
  method,
  token,
  body: reqBody
}) {
  let res = await request({
    url,
    qs,
    method,
    headers: {
      Authorization: `Basic ${token}`,
      'X-Atlassian-Token': 'no-check' // prevent "XSRF check failed"
    },
    json: true,
    body: reqBody
  });

  let { body } = res;

  if (body) {
    if (body.errors) {
      throw body;
    }

    let { values } = body;

    if (values) {
      if (!body.isLastPage) {
        values.concat(await bitbucketRequest({
          url,
          qs: Object.assign({}, qs, {
            start: body.nextPageStart
          }),
          method,
          token,
          body
        }));
      }

      return values;
    }
  }

  return body;
}

module.exports = bitbucketRequest;
