'use strict';

const buildBbUrl = require('./build-bitbucket-url');
const utils = require('./utils');

function getReviewers(pr) {
  return pr.reviewers.map(({ user }) => user.name);
}

async function createPullRequest({
  token,
  endpoint,
  branch,
  project,
  repo,
  title = 'test title',
  description = 'test description',
  reviewers = [],
  prToRebase,
  retainOriginalReviewers,
  templateValues
}) {
  let method, id, version;
  if (prToRebase) {
    method = 'PUT';
    id = prToRebase.id;
    version = prToRebase.version + 1;
  } else {
    method = 'POST';
  }

  if (prToRebase && retainOriginalReviewers) {
    reviewers = getReviewers(prToRebase);
  } else if (typeof reviewers === 'string') {
    reviewers = await utils.callbackHook({
      url: reviewers,
      templateValues
    });
  }

  let repoUrl = buildBbUrl({
    endpoint,
    project,
    repo,
    type: 'PULL_REQUEST',
    id
  });

  let repository = {
    slug: repo,
    name: null,
    project: {
      key: project
    }
  };

  let body = {
    version,
    title,
    description,
    state: 'OPEN',
    open: true,
    closed: false,
    fromRef: {
      id: `refs/heads/${branch}`,
      repository
    },
    toRef: {
      id: 'refs/heads/master',
      repository
    },
    // locked: false,
    reviewers: reviewers.map(name => ({
      user: {
        name
      }
    }))
  };

  let pr = await utils.bbReq({
    url: repoUrl,
    method,
    token,
    body
  });

  return {
    title: pr.title,
    branch: pr.fromRef.displayId,
    description: pr.description,
    reviewers: getReviewers(pr)
  };
}

module.exports = createPullRequest;
