'use strict';

const url = require('url');
const buildBbUrl = require('./build-bitbucket-url');
const bbReq = require('./bitbucket-request');
const { deleteRemoteBranch } = require('./repo-utils');

async function declinePullRequest({
  token,
  repoPath,
  pr,
  deleteBranch
}) {
  let parsed = url.parse(pr.links.self[0].href);

  let repoUrl = buildBbUrl({
    endpoint: `${parsed.protocol}//${parsed.host}`,
    project: pr.toRef.repository.project.key,
    repo: pr.toRef.repository.name,
    type: 'PULL_REQUEST',
    id: pr.id
  });

  await bbReq({
    url: `${repoUrl}/decline?version=${pr.version}`,
    method: 'POST',
    token,
    json: false
  });

  if (deleteBranch) {
    await deleteRemoteBranch({
      branch: pr.fromRef.displayId,
      repoPath
    });
  }
}

module.exports = declinePullRequest;
