'use strict';

const getPrs = require('./get-pull-requests');
const delPr = require('./delete-pull-request');
const getRepoPath = require('./get-repo-path');
const { mergeConfigForRepo } = require('./config-utils');

async function deleteAllFromRepo({
  repoPath,
  token,
  endpoint,
  project,
  repo,
  user,
  deleteBranch
}) {
  let prs = await getPrs({
    project,
    repo,
    token,
    endpoint,
    user
  });

  return await Promise.all(prs.map(async pr => {
    await delPr({
      token,
      repoPath,
      pr,
      deleteBranch
    });

    return {
      title: pr.title,
      branch: pr.fromRef.displayId
    };
  }));
}

async function deleteAllPullRequests({
  config,
  token
}) {
  let {
    cachePath,
    repositories
  } = config;

  return (await Promise.all(repositories.map(async repo => {
    let {
      endpoint,
      user,
      deleteBranch
    } = mergeConfigForRepo(config, repo);

    let repoPath = getRepoPath(cachePath, repo.name);

    return {
      repo,
      prs: await deleteAllFromRepo({
        repoPath,
        token,
        endpoint,
        project: repo.project,
        repo: repo.name,
        user,
        deleteBranch
      })
    };
  }))).reduce((output, { repo, prs }) => {
    output[`${repo.project}/${repo.name}`] = prs;
    return output;
  }, {});
}

module.exports = deleteAllPullRequests;
