'use strict';

const buildBbUrl = require('./build-bitbucket-url');
const bbReq = require('./bitbucket-request');

async function getPullRequests({
  project,
  repo,
  token,
  endpoint,
  user
}) {
  let url = buildBbUrl({
    endpoint,
    project,
    repo,
    type: 'PULL_REQUEST'
  });

  async function _getPrs(state) {
    let prs = await bbReq({
      url,
      token,
      qs: {
        at: 'refs/heads/master',
        state,
        withAttributes: false,
        withProperties: false
      }
    });

    return prs.filter(pr => pr.author.user.name === user);
  }

  let [open, declined] = await Promise.all([
    _getPrs('OPEN'),
    _getPrs('DECLINED')
  ]);

  return open.concat(declined);
}

module.exports = getPullRequests;
