'use strict';

const run = require('./run');
const runWithRegistry = require('./run-with-registry');

async function isRebaseNeeded({
  branch,
  repoPath
}) {
  try {
    await run(`git checkout -B ${branch} origin/${branch}`, { cwd: repoPath });
  } catch (err) {
    // branch was deleted from PR
    return false;
  }
  let parent = await run('git rev-parse HEAD~1', { cwd: repoPath });
  let master = await run('git rev-parse master', { cwd: repoPath });
  await run('git checkout master', { cwd: repoPath });
  await run(`git branch -D ${branch}`, { cwd: repoPath });
  return parent !== master;
}

async function updateDependency({
  name,
  newRange,
  repoPath,
  registry,
  shouldResetPackageJson
}) {
  await runWithRegistry(`yarn upgrade ${name}@${newRange} --ignore-engines`, registry, { cwd: repoPath });
  if (shouldResetPackageJson) {
    await run('git checkout package.json', { cwd: repoPath });
  }
  await run('git add .', { cwd: repoPath });
}

async function createBranch({
  branch,
  repoPath,
  message = 'bb test'
}) {
  await run(`git checkout -B ${branch}`, { cwd: repoPath });
  await run(`git commit -m "${message}"`, { cwd: repoPath });
  await run(`git push --set-upstream origin ${branch} --force`, { cwd: repoPath });
  await run('git checkout master', { cwd: repoPath });
  await run(`git branch -D ${branch}`, { cwd: repoPath });
}

async function deleteRemoteBranch({
  branch,
  repoPath
}) {
  await run(`git push -d origin ${branch}`, { cwd: repoPath });
}

module.exports.isRebaseNeeded = isRebaseNeeded;
module.exports.updateDep = updateDependency;
module.exports.createBranch = createBranch;
module.exports.deleteRemoteBranch = deleteRemoteBranch;
