'use strict';

const replaceTemplate = require('./replace-template');
const utils = require('./utils');
const formatRepoUrl = require('./format-repo-url');

async function getUrlFromTemplate({
  shouldCheckRegistry = true,
  urlTemplate,
  templateValues,
  name,
  repoPath
}) {
  let packageUrl;
  if (urlTemplate) {
    packageUrl = replaceTemplate(urlTemplate, templateValues);
  } else if (shouldCheckRegistry) {
    let repoUrl = await utils.getRepoUrl({
      name,
      repoPath
    });
    packageUrl = formatRepoUrl(repoUrl);
  }
  return packageUrl;
}

async function getPackagesTemplateValue({
  meta,
  repoPath
}) {
  let packages = `| Package | Old Range | New Range | Old Version | New Version |
|---|---|---|---|---|`;

  for (let name of Object.keys(meta)) {
    let {
      oldRange,
      newRange,
      oldVersion,
      newVersion,
      isMasterUpToDate,
      packageConfig
    } = meta[name];

    if (isMasterUpToDate) {
      continue;
    }

    let {
      endpoint,
      user,
      project,
      branch,
      name: repo,
      urlTemplate
    } = packageConfig;

    let templateValues = {
      endpoint,
      user,
      project,
      repo,
      branch,
      package: name,
      oldRange,
      newRange,
      oldVersion,
      newVersion
    };

    let url = await getUrlFromTemplate({
      urlTemplate,
      templateValues,
      name,
      repoPath
    });

    let values = [
      `[${name}](${url})`,
      oldRange,
      newRange,
      oldVersion,
      newVersion
    ];

    packages += `\n| ${values.join(' | ')} |`;
  }

  return packages;
}

module.exports.getUrlFromTemplate = getUrlFromTemplate;
module.exports.getPackagesTemplateValue = getPackagesTemplateValue;
